@@ -6,7 +6,7 @@ var indexSectionsWithContent =
   3: "abcdefghilmnoprstvwx",
   4: "abcdefhimnoprstuvwx",
   5: "x",
-  6: "wx"
+  6: "w"
 };
 
 var indexSectionNames =
