@@ -43,6 +43,8 @@ var NAVTREE =
       [ "DEPRECATED", "index.html#DEPRECATED", null ]
     ] ],
     [ "Release Notes", "index.html#xmlreleasenotes", [
+      [ "xml Module Version 1.6.1", "index.html#xml161", null ],
+      [ "xml Module Version 1.6", "index.html#xml16", null ],
       [ "xml Module Version 1.5.3", "index.html#xml153", null ],
       [ "xml Module Version 1.5.2", "index.html#xml152", null ],
       [ "xml Module Version 1.5.1", "index.html#xml151", null ],
@@ -56,7 +58,6 @@ var NAVTREE =
       [ "xml Module Version 1.2", "index.html#xml12", null ],
       [ "xml Module Version 1.1", "index.html#xml11", null ]
     ] ],
-    [ "XML Generation Options", "xml_generation_opts.html", null ],
     [ "Deprecated List", "deprecated.html", null ],
     [ "Modules", "modules.html", "modules" ],
     [ "Namespaces", "namespaces.html", [
