@@ -6,7 +6,7 @@ var indexSectionsWithContent =
   3: "abcdefghilmnoprstvx",
   4: "ehmnx",
   5: "x",
-  6: "dqx"
+  6: "dq"
 };
 
 var indexSectionNames =
